==> slideshow_creator-5.x-1.16.tar.gz: slideshow_creator/slideshow_creator developer.js <==
// $Id: slideshow_creator\040developer.js,v 1.1.2.1 2007/03/19 02:36:00 brmassa Exp $
/*******************************************************************************
                     D R U P A L    M O D U L E
********************************************************************************
Module Name        : Slideshow Creator
Original Author    : Bruno Massa http://drupal.org/user/67164
General Links
Project Page       : http://drupal.org/project/slideshow_creator
Support Queue      : http://drupal.org/project/issues/slideshow_creator

*******************************************************************************/

// Preload all images before start the slideshow
function ssc_preload(ss,j) {
  var n = ssc[ss][j];
  if(n) {
    n.image = new Image();
    n.image.src = n.src;
    n.image.onload = function() {ssc_preload(ss,++j);}
  }
}

// Set the previous slide as the current slide
function ssc_previous(ss) {
  if(!ssc[ss][--ssc[ss].current]) ssc[ss].current=ssc[ss].total;
  ssc_update(ss);
}

// Set the next slide as the current slide
function ssc_next(ss) {
  if(!ssc[ss][++ssc[ss].current]) ssc[ss].current=1;
  ssc_update(ss);
}

// Update all slide attributes
function ssc_update(ss) {
  if (ssc[ss].rotate>0) {clearTimeout(ssc[ss].timeout["a1"]);}
  var obj=ssc[ss][ssc[ss].current];
  $("#ssc-image-" + ss).fadeIn(ssc[ss].blend/2 * 1000);
  $("#ssc-description-" + ss).html(obj.description);
  $("#ssc-title-" + ss).html(obj.title);
  $("#ssc-current-" + ss).html(ssc[ss].current);
  $("#ssc-limage-" + ss).attr("href", obj.link).attr("target", obj.target);
  $("#ssc-ltitle-" + ss).attr("href", obj.link);
  $("#ssc-image-" + ss + " img").attr("src", obj.src).attr("alt", obj.title);
  $("#ssc-image-" + ss).show();
  if (ssc[ss].rotate>0) ssc[ss].timeout["a1"] = setTimeout("ssc_next('"+ss+"')", ssc[ss].rotate*1000);
}

// initialize all variables and make "previous" and "next" buttons call js functions
function ssc_init() {
  ssc = Drupal.settings.ssc;
  for (ss in ssc) {
    ssc_preload(ss,1);
    $("#ssc-previous-" + ss).click(function() {ssc_previous(this.id.replace(/ssc-previous-/,"")); return false;});
    $("#ssc-next-" + ss).click(function() {ssc_next(this.id.replace(/ssc-previous-/,"")); return false;});
    $("#ssc-image-" + ss).mouseover(function() {
        ss = this.id.replace(/ssc-image-/,"");
        if (ssc[ss].rotate>0) clearTimeout(ssc[ss].timeout["a1"]);
      });
    $("#ssc-image-" + ss).mouseout(function() {
        ss = this.id.replace(/ssc-image-/,"");
        if (ssc[ss].rotate>0) ssc[ss].timeout["a1"]=setTimeout("ssc_next('" + ss + "')", ssc[ss].rotate*1000);
      });
    if (ssc[ss].blend>ssc[ss].rotate) ssc[ss].blend=ssc[ss].rotate;
    if (ssc[ss].rotate>0) ssc[ss].timeout["a1"]=setTimeout("ssc_next('" + ss + "')", ssc[ss].rotate*1000);
  }
}

$(document).ready(function() {ssc_init();})

==> slideshow_creator-5.x-1.18.tar.gz: slideshow_creator/slideshow_creator developer.js <==
// $Id: slideshow_creator\040developer.js,v 1.1.2.2 2007/04/09 05:06:32 brmassa Exp $
/*******************************************************************************
                     D R U P A L    M O D U L E
********************************************************************************
Module Name        : Slideshow Creator
Original Author    : Bruno Massa http://drupal.org/user/67164
General Links
Project Page       : http://drupal.org/project/slideshow_creator
Support Queue      : http://drupal.org/project/issues/slideshow_creator

*******************************************************************************/

// Preload all images before start the slideshow
function ssc_preload(ss,j) {
  var n = ssc[ss][j];
  if(n) {
    n.image = new Image();
    n.image.src = n.src;
    n.image.onload = function() {ssc_preload(ss,++j);}
  }
}

// Set the previous slide as the current slide
function ssc_previous(ss) {
  if(!ssc[ss][--ssc[ss].current]) ssc[ss].current=ssc[ss].total;
  ssc_update(ss);
}

// Set the next slide as the current slide
function ssc_next(ss) {
  if(!ssc[ss][++ssc[ss].current]) ssc[ss].current=1;
  ssc_update(ss);
}

// Update all slide attributes
function ssc_update(ss) {
  if (ssc[ss].rotate>0) {clearTimeout(ssc[ss].timeout["a1"]);}
  var obj=ssc[ss][ssc[ss].current];
  $("#ssc-image-" + ss).fadeIn(ssc[ss].blend/2 * 1000);
  $("#ssc-description-" + ss).html(obj.description);
  $("#ssc-title-" + ss).html(obj.title);
  $("#ssc-current-" + ss).html(ssc[ss].current);
  $("#ssc-limage-" + ss).attr("href", obj.link).attr("target", obj.target);
  $("#ssc-ltitle-" + ss).attr("href", obj.link);
  $("#ssc-image-" + ss + " img").attr("src", obj.src).attr("alt", obj.title);
  $("#ssc-image-" + ss).show();
  if (ssc[ss].rotate>0) ssc[ss].timeout["a1"] = setTimeout("ssc_next('"+ss+"')", ssc[ss].rotate*1000);
}

// initialize all variables and make "previous" and "next" buttons call js functions
function ssc_init() {
  ssc = Drupal.settings.ssc;
  for (ss in ssc) {
    ssc_preload(ss,1);
    $("#ssc-previous-" + ss).click(function() {ssc_previous(this.id.replace(/ssc-previous-/,"")); return false;});
    $("#ssc-next-" + ss).click(function() {ssc_next(this.id.replace(/ssc-next-/,"")); return false;});
    $("#ssc-image-" + ss).mouseover(function() {
        ss = this.id.replace(/ssc-image-/,"");
        if (ssc[ss].rotate>0) clearTimeout(ssc[ss].timeout["a1"]);
      });
    $("#ssc-image-" + ss).mouseout(function() {
        ss = this.id.replace(/ssc-image-/,"");
        if (ssc[ss].rotate>0) ssc[ss].timeout["a1"]=setTimeout("ssc_next('" + ss + "')", ssc[ss].rotate*1000);
      });
    if (ssc[ss].blend>ssc[ss].rotate) ssc[ss].blend=ssc[ss].rotate;
    if (ssc[ss].rotate>0) ssc[ss].timeout["a1"]=setTimeout("ssc_next('" + ss + "')", ssc[ss].rotate*1000);
  }
}

$(document).ready(function() {ssc_init();})
